# Generated by roxygen2: do not edit by hand

S3method(print,cmr_allocation)
S3method(print,cmr_multiarm)
S3method(print,cmr_multiple_outcomes)
S3method(print,cmr_proxy)
S3method(print,cmr_stratified)
S3method(print,cmr_two_arm)
S3method(print,cmr_unbounded)
S3method(print,summary.cmr_result)
S3method(summary,cmr_multiarm)
S3method(summary,cmr_multiple_outcomes)
S3method(summary,cmr_proxy)
S3method(summary,cmr_stratified)
S3method(summary,cmr_two_arm)
S3method(summary,cmr_unbounded)
export(activation_threshold_bernoulli)
export(activation_threshold_bounded)
export(assign_additive_regularized_neyman)
export(assign_balance)
export(assign_exponential_regularized_neyman)
export(assign_feasible_neyman)
export(assign_multiarm_balance)
export(assign_multiarm_neyman)
export(assign_neyman)
export(assign_stratified_balance)
export(assign_stratified_neyman)
export(assign_trimmed_neyman)
export(binary_rectangle_corners)
export(binary_rectangle_regret)
export(boundary_indicator)
export(boundary_rate)
export(break_even_pilot_share)
export(certificate_valid)
export(cmr_binary)
export(cmr_binary_from_rectangle)
export(cmr_delayed_outcome)
export(cmr_multiarm)
export(cmr_multiarm_from_rectangle)
export(cmr_multiple_outcomes)
export(cmr_plan)
export(cmr_proxy)
export(cmr_stratified)
export(cmr_stratified_from_rectangle)
export(cmr_two_arm)
export(cmr_two_arm_from_rectangle)
export(cmr_unbounded)
export(cmr_unbounded_from_rectangle)
export(coverage_indicator)
export(folded_binomial_pmf)
export(folded_binomial_tails)
export(multiarm_oracle_variance)
export(multiarm_rectangle_vertices)
export(multiarm_regret)
export(multiarm_variance_objective)
export(oracle_variance)
export(pilot_plan)
export(pilot_viability_band)
export(realize_allocation)
export(rectangle_bernoulli_binary)
export(rectangle_bernoulli_two_arm)
export(rectangle_binary)
export(rectangle_bounded_binary)
export(rectangle_bounded_two_arm)
export(rectangle_delayed_outcome)
export(rectangle_multiarm)
export(rectangle_multiple_outcomes)
export(rectangle_proxy)
export(rectangle_stratified)
export(rectangle_two_arm)
export(rectangle_unbounded)
export(regret)
export(saving_vs_balance)
export(share_of_oracle_gain)
export(stratified_oracle_variance)
export(stratified_rectangle_vertices)
export(stratified_regret)
export(stratified_variance_objective)
export(variance_bounds_bernoulli_exact)
export(variance_bounds_martinez_taboada_ramdas)
export(variance_bounds_maurer_pontil)
export(variance_bounds_unbounded_mom)
export(variance_objective)
